package com.rjconsultores.ventaboletos.relatorios.impl;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

import net.sf.jasperreports.engine.data.JRBeanCollectionDataSource;

import org.apache.commons.lang.StringUtils;

import com.rjconsultores.ventaboletos.relatorios.utilitarios.Checkin;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.utilerias.DateUtil;

public class RelatorioCheckinModoConsolidadoPorUsuario extends Relatorio {

	public RelatorioCheckinModoConsolidadoPorUsuario(Map<String, Object> parametros, Connection conexao) {
		super(parametros, conexao);
	}
	
	List<Integer> lsInt;

	@Override
	protected void processaParametros() throws Exception {

		Integer corridaId = (Integer) getParametros().get("CORRIDA_ID");
		Integer origenId = (Integer) getParametros().get("ORIGEN_ID");
		String idsBilheteiros = (String) getParametros().get("IDS_BILHETEIROS");
		Date fecInicio = (Date) getParametros().get("DATA_INICIAL");
		Date fecFinal = (Date) getParametros().get("DATA_FINAL");
		fecInicio = DateUtil.inicioFecha(fecInicio);
		fecFinal = DateUtil.fimFecha(fecFinal);
	
		
		if (StringUtils.isNotBlank(idsBilheteiros)) {
			String []ls = idsBilheteiros.split(",");
			lsInt = new ArrayList<Integer>();
			for(String i : ls){
				lsInt.add(new Integer(Integer.parseInt(i.trim())));
			}
		}

		String sql = getSql(corridaId, origenId, idsBilheteiros);

		PreparedStatement pstmt = getConexao().prepareStatement(sql);
		
		int index = 1;
		pstmt.setTimestamp(index++, new java.sql.Timestamp(fecInicio.getTime()));
		pstmt.setTimestamp(index++, new java.sql.Timestamp(fecFinal.getTime()));

		if (corridaId != null) {
			pstmt.setInt(index++, corridaId);
		}

		if (origenId != null) {
			pstmt.setInt(index++, origenId);
		}
		
		if (StringUtils.isNotBlank(idsBilheteiros)) {
			for(int i = 0 ; i < lsInt.size() ; i++){
				pstmt.setInt(index++, lsInt.get(i));//Object("idsBilheteiros", lsInt.toArray());
			}
		}

		List<Checkin> checkins = new ArrayList<Checkin>();

		ResultSet rset = pstmt.executeQuery();
		while (rset.next()) {

			Checkin checkin = new Checkin();
			checkin.setBoletoId(rset.getLong("boleto_Id"));
			checkin.setNumFolioSistema(rset.getString("numoperacion"));
			checkin.setOrigen(rset.getString("descparada"));
			checkin.setCorridaId(rset.getInt("corrida_id"));
			checkin.setFeccorrida(rset.getTimestamp("feccorrida"));
			checkin.setDataVenda(rset.getTimestamp("datavenda"));
			checkin.setDataCancelado(rset.getTimestamp("datacancelado"));
			checkin.setDataRemarcacao(rset.getTimestamp("dataremarcacao"));
			checkin.setNombUsuario(rset.getString("nombusuario"));
			checkin.setCveusuario(rset.getString("cveusuario"));
			checkin.setUsuariovenda(rset.getString("usuariovenda"));
			checkin.setUsuarioNowShow(rset.getString("usuarioNowShow"));
			checkin.setUsuariocheckin(rset.getString("usuariocheckin"));

			checkins.add(checkin);
		}

		setLsDadosRelatorio(checkins);
	}

	public void setLsDadosRelatorio(List<Checkin> checkins) {
		this.setCollectionDataSource(new JRBeanCollectionDataSource(checkins));
	}

	private String getSql(Integer corridaId, Integer origenId, String idsBilheteiros) {

		StringBuffer sql = new StringBuffer();
		sql.append("select b.boleto_id, o.descparada, b.corrida_id, ");
		sql.append("       case when b.numfoliosistema is not null  ");
		sql.append("          then b.numfoliosistema else b.numoperacion ");
		sql.append("       end  numoperacion, ");
		sql.append("       b.feccorrida, ");
		sql.append("       bc.datavenda, ");
		sql.append("       bc.datacancelado, "); 
		sql.append("       bc.dataremarcacao, "); 
		sql.append("       u.cveusuario as usuariovenda, ");
		sql.append("       uc.cveusuario as usuarioNowShow, ");
		sql.append("       case when uca.cveusuario is not null then uca.cveusuario else ucr.cveusuario end as usuariocheckin, ");
		sql.append("       u.cveusuario, ");
		sql.append("       u.nombusuario ");
		sql.append("  from boleto b left join boleto_checkin bc on (b.boleto_id = bc.boletooriginal_id) ");
		sql.append("               inner join parada o on b.origen_id = o.parada_id ");
		sql.append("                left join checkin_automatico ca on (ca.boleto_id = b.boleto_id)");
		sql.append("                left join checkin_cerrado cc on (cc.feccorrida   = b.feccorrida and ");
		sql.append("                                                 cc.corrida_id   = b.corrida_id and ");
		sql.append("                                                 cc.origen_id    = b.origen_id) ");
		//sql.append("                                               and cc.destino_id   = b.destino_id) ");
		sql.append("                left join usuario          u on (u.usuario_id    = b.usuario_id)");
		sql.append("                left join usuario         uc on (uc.usuario_id   = bc.usuario_id)");
		sql.append("                left join usuario        uca on (uca.usuario_id  = ca.usuario_id)");
		sql.append("                left join usuario        ucr on (ucr.usuario_id  = cc.usuario_id)");
		sql.append("");
		sql.append(" where b.activo = 1  ");
		sql.append("and bc.FECMODIF between ? and  ? ");
		sql.append(corridaId == null ? "" : " and b.corrida_id = ? ");
		sql.append(origenId == null ? "" : " and b.origen_id = ? ");
		sql.append((lsInt == null || lsInt.size() == 0) ? "" : " and u.USUARIO_ID in ( "+ createIn(lsInt.size()) + ") ");
		
		sql.append(" order by 3, 4, 7 desc");

		return sql.toString();
	}
	
	public String createIn(int n) {
		if(n > 0){
			String str = StringUtils.repeat(" ? ,", n);
		    return str.substring(0, str.length()-1);
		}else{
			return "";
		}
		
	}

}
