package com.rjconsultores.ventaboletos.web.gui.controladores.configuracioneccomerciales;

import java.util.HashMap;
import java.util.Map;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Checkbox;
import org.zkoss.zul.Paging;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.Transportadora;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderPadrao;

import lombok.Getter;
import lombok.Setter;

@Getter
@Setter
@Controller("busquedaTransportadoraController")
@Scope("prototype")
public class BusquedaTransportadoraController extends MyGenericForwardComposer {

	private static Logger log = LogManager.getLogger(BusquedaTransportadoraController.class); 
	private static final long serialVersionUID = 1L;
	@Autowired
	private transient PagedListWrapper<Transportadora> plwpagingTransportadora;
	
	private MyListbox transportadoraList;
	private Paging pagingTransportadora;
	private Textbox txtNit;
	private Textbox txtNome;
	private Checkbox chkInativos;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		super.doAfterCompose(comp);
		
		transportadoraList.setItemRenderer(new RenderPadrao<Transportadora>(Transportadora.class));
		transportadoraList.addEventListener("onDoubleClick", new EventListener() {

			@Override
			public void onEvent(Event event) throws Exception {
				Transportadora cc = (Transportadora) transportadoraList.getSelected();
				verTransportadora(cc);
			}
		});

		refreshLista();
		
		txtNit.focus();
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void verTransportadora(Transportadora gc) {
		if (gc == null) {
			return;
		}

		Map args = new HashMap();
		args.put("transportadora", gc);
		args.put("transportadoraList", transportadoraList);

		openWindow("/gui/configuraciones_comerciales/negcorporativos/editarTransportadora.zul",
				Labels.getLabel("editarTransportadoraController.window.title"), args, MODAL);
	}

	private void refreshLista() {
		HibernateSearchObject<Transportadora> configCategoriaBusqueda = new HibernateSearchObject<Transportadora>(
																				Transportadora.class,
																				pagingTransportadora.getPageSize());

		if (txtNit.getText().length() > 0) {
			configCategoriaBusqueda.addFilterLike("nit", "%" + txtNit.getText().trim().concat("%"));
		}
		
		if (txtNome.getText().length() > 0) {
			configCategoriaBusqueda.addFilterLike("nomeTransportadora", "%" + txtNome.getText().trim().concat("%"));
		}
		
		if(!chkInativos.isChecked()) {
			configCategoriaBusqueda.addFilterEqual("activo", Boolean.TRUE);
		}
		configCategoriaBusqueda.addSortAsc("nomeTransportadora");

		plwpagingTransportadora.init(configCategoriaBusqueda, transportadoraList, pagingTransportadora);

		if (transportadoraList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("busquedaTransportadoraController.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
				log.error(ex);
			}
		}
	}

	public void onClick$btnPesquisa(Event ev) {
		refreshLista();
	}

	public void onClick$btnRefresh(Event ev) {
		refreshLista();
	}

	public void onClick$btnNovo(Event ev) {
		verTransportadora(new Transportadora());
	}
		
}
