package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.sql.DataSource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zul.Bandbox;
import org.zkoss.zul.Datebox;
import org.zkoss.zul.ListModelList;
import org.zkoss.zul.Paging;
import org.zkoss.zul.Radiogroup;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.entidad.PuntoVenta;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioVendasInternetPTA;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioVendasPTA;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioVendasPTA.SituacaoBoleto;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.service.EmpresaService;
import com.rjconsultores.ventaboletos.utilerias.DateUtil;
import com.rjconsultores.ventaboletos.web.utilerias.MyComboboxEstandar;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderPuntoVentaSimple;
import com.trg.search.Filter;

@Controller("relatorioVendasPTAController")
@Scope("prototype")
public class RelatorioVendasPTAController extends MyGenericForwardComposer {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private static final String TODOS_VALUE = new Integer(-1).toString();
	private static final String TODOS = "TODAS";
	@Autowired
	private EmpresaService empresaService;
	private List<Empresa> lsEmpresa;
	private MyComboboxEstandar cmbEmpresa;
	private MyComboboxEstandar cmbSituacao;
	private Datebox datInicial;
	private Datebox datFinal;
	@Autowired
	private DataSource dataSourceRead;
	private MyListbox puntoVentaList;;
	private MyListbox puntoVentaSelList;
	private Paging pagingPuntoVenta;
	private Bandbox bbPesquisaPuntoVenta;
	@Autowired
	private transient PagedListWrapper<PuntoVenta> plwPuntoVenta;
	private ArrayList<PuntoVenta> lsNumPuntoVenta = new ArrayList<PuntoVenta>();
	private Radiogroup rgLayout;

	private Textbox txtPalavraPesquisa;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		super.doAfterCompose(comp);

		lsEmpresa = empresaService.obtenerTodos();
		cambiarTipoSituacao();
		puntoVentaList.setItemRenderer(new RenderPuntoVentaSimple());
		puntoVentaSelList.setItemRenderer(new RenderPuntoVentaSimple());
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void executarRelatorio() throws Exception {
		Relatorio relatorio;

		Map<String, Object> parametros = new HashMap<String, Object>();

		Timestamp dataInicio = new Timestamp((DateUtil.inicioFecha((java.util.Date) this.datInicial.getValue()).getTime()));
		Timestamp dataFinal = new Timestamp((DateUtil.fimFecha((java.util.Date) this.datFinal.getValue()).getTime()));

		parametros.put("DATA_INICIAL", dataInicio);
		parametros.put("DATA_FINAL", dataFinal);

		Empresa empresa = (Empresa) cmbEmpresa.getSelectedItem().getValue();
		SituacaoBoleto situacaoBoleto = (SituacaoBoleto) cmbSituacao.getSelectedItem().getValue();
		lsNumPuntoVenta = new ArrayList(Arrays.asList(puntoVentaSelList.getData()));

		if (lsNumPuntoVenta.size() > 0) {
			String puntoVentaExpression = null;
			for (PuntoVenta p : lsNumPuntoVenta) {
				if (lsNumPuntoVenta.indexOf(p) == 0) {
					puntoVentaExpression = p.getPuntoventaId().toString();
				} else {
					puntoVentaExpression += ", " + p.getPuntoventaId().toString();
				}
			}
			parametros.put("PUNTOVENTA_ID", puntoVentaExpression);
			parametros.put("PUNTOVENTA", puntoVentaExpression);
		} else {
			parametros.put("PUNTOVENTA_ID", TODOS_VALUE);
			parametros.put("PUNTOVENTA", TODOS);
		}

		parametros.put("EMPRESA", empresa);
		parametros.put("SITUACAO_BOLETO", situacaoBoleto);
		parametros.put("NOME_EMPRESA", empresa.getNombempresa());

		parametros.put("TITULO", Labels.getLabel("relatorioVendasPTAController.window.title"));
		if (rgLayout.getSelectedItem().getValue().equals("LAYOUT_1")){
			relatorio = new RelatorioVendasPTA(parametros, dataSourceRead.getConnection());
		}else{
			relatorio = new RelatorioVendasInternetPTA(parametros, dataSourceRead.getConnection());
		}
		
		Map args = new HashMap();
		args.put("relatorio", relatorio);

		openWindow("/component/reportView.zul",	Labels.getLabel("relatorioVendasPTAController.window.title"), args, MODAL);
	}

	public void onSelect$puntoVentaList(Event ev) {

	}

	public void onClick$btnLimpar(Event ev) {
		limparPesquisaAgencia();
	}

	public void onClick$btnPesquisa(Event ev) {
		executarPesquisa();
	}

	private void executarPesquisa() {
		HibernateSearchObject<PuntoVenta> puntoVentaBusqueda = new HibernateSearchObject<PuntoVenta>(PuntoVenta.class,
				pagingPuntoVenta.getPageSize());

		puntoVentaBusqueda.addFilterOr(Filter.like("nombpuntoventa", "%" + txtPalavraPesquisa.getText().trim().toUpperCase().concat("%")), Filter.like("numPuntoVenta", "%" + txtPalavraPesquisa.getText().trim().toUpperCase().concat("%")));

		puntoVentaBusqueda.addSortAsc("nombpuntoventa");

		puntoVentaBusqueda.addFilterEqual("activo", Boolean.TRUE);

		plwPuntoVenta.init(puntoVentaBusqueda, puntoVentaList, pagingPuntoVenta);

		if (puntoVentaList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("relatorioReceitaDiariaAgenciaController.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
			}
		}
	}

	private void limparPesquisaAgencia() {
		puntoVentaList.clearSelection();

		lsNumPuntoVenta.clear();
		this.bbPesquisaPuntoVenta.setValue("");
	}

	public void onDoubleClick$puntoVentaList(Event ev) {

		PuntoVenta puntoVentaSel = (PuntoVenta) puntoVentaList.getSelected();
		puntoVentaSelList.addItemNovo(puntoVentaSel);

	}
	
	public void onCheck$rdExecutarRelatorio(Event ev) {
		cambiarTipoSituacao();
	}
	public void onCheck$rdInternetPta(Event ev) {
		cambiarTipoSituacao();
	}
	
	private void cambiarTipoSituacao(){

		if (rgLayout.getSelectedItem().getValue().equals("LAYOUT_1")) {
			List<SituacaoBoleto> lsSituacaoAux = new ArrayList<SituacaoBoleto>();
			for (SituacaoBoleto situacao : SituacaoBoleto.values()) {
				if (!(situacao.getCodigo() == 2 || situacao.getCodigo() == 3)) {
					lsSituacaoAux.add(situacao);
				}
			}
			cmbSituacao.setModel(new ListModelList(lsSituacaoAux));
		} else {
			cmbSituacao.setModel(new ListModelList(Arrays.asList(SituacaoBoleto.values())));
		}
	}

	public void onDoubleClick$puntoVentaSelList(Event ev) {

		PuntoVenta puntoVentaSel = (PuntoVenta) puntoVentaSelList.getSelected();
		puntoVentaSelList.removeItem(puntoVentaSel);

	}

	public void onClick$btnExecutarRelatorio(Event ev) throws Exception {
		executarRelatorio();
	}

	public List<Empresa> getLsEmpresa() {
		return lsEmpresa;
	}

	public void setLsEmpresa(List<Empresa> lsEmpresa) {
		this.lsEmpresa = lsEmpresa;
	}

	public MyListbox getPuntoVentaList() {
		return puntoVentaList;
	}

	public void setPuntoVentaList(MyListbox puntoVentaList) {
		this.puntoVentaList = puntoVentaList;
	}

	public Paging getPagingPuntoVenta() {
		return pagingPuntoVenta;
	}

	public void setPagingPuntoVenta(Paging pagingPuntoVenta) {
		this.pagingPuntoVenta = pagingPuntoVenta;
	}

	public Textbox getTxtPalavraPesquisa() {
		return txtPalavraPesquisa;
	}

	public void setTxtPalavraPesquisa(Textbox txtPalavraPesquisa) {
		this.txtPalavraPesquisa = txtPalavraPesquisa;
	}

	public Bandbox getBbPesquisaPuntoVenta() {
		return bbPesquisaPuntoVenta;
	}

	public void setBbPesquisaPuntoVenta(Bandbox bbPesquisaPuntoVenta) {
		this.bbPesquisaPuntoVenta = bbPesquisaPuntoVenta;
	}

	public MyListbox getPuntoVentaSelList() {
		return puntoVentaSelList;
	}

	public void setPuntoVentaSelList(MyListbox puntoVentaSelList) {
		this.puntoVentaSelList = puntoVentaSelList;
	}
}
